==> gradle-src-2.10-1-any.pkg.tar.xz: usr/share/java/gradle/src/platform-play/org/gradle/play/internal/CleaningPlayToolCompiler.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.play.internal;

import org.gradle.api.internal.TaskOutputsInternal;
import org.gradle.api.tasks.WorkResult;
import org.gradle.language.base.internal.compile.Compiler;
import org.gradle.language.base.internal.tasks.SimpleStaleClassCleaner;
import org.gradle.play.internal.spec.PlayCompileSpec;

public class CleaningPlayToolCompiler<T extends PlayCompileSpec> implements Compiler<T> {
    private final Compiler<T> delegate;
    private TaskOutputsInternal taskOutputs;

    public CleaningPlayToolCompiler(Compiler<T> delegate, TaskOutputsInternal taskOutputs) {
        this.delegate = delegate;
        this.taskOutputs = taskOutputs;
    }

    public WorkResult execute(T spec) {
        SimpleStaleClassCleaner cleaner = new SimpleStaleClassCleaner(taskOutputs);
        cleaner.setDestinationDir(spec.getDestinationDir());
        cleaner.execute();
        return delegate.execute(spec);
    }
}

==> gradle-src-5.2.1-1-any.pkg.tar.xz: usr/share/java/gradle/src/platform-play/org/gradle/play/internal/CleaningPlayToolCompiler.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.play.internal;

import org.gradle.api.internal.TaskOutputsInternal;
import org.gradle.api.tasks.WorkResult;
import org.gradle.language.base.internal.compile.Compiler;
import org.gradle.language.base.internal.tasks.SimpleStaleClassCleaner;
import org.gradle.play.internal.spec.PlayCompileSpec;

public class CleaningPlayToolCompiler<T extends PlayCompileSpec> implements Compiler<T> {
    private final Compiler<T> delegate;
    private TaskOutputsInternal taskOutputs;

    public CleaningPlayToolCompiler(Compiler<T> delegate, TaskOutputsInternal taskOutputs) {
        this.delegate = delegate;
        this.taskOutputs = taskOutputs;
    }

    @Override
    public WorkResult execute(T spec) {
        SimpleStaleClassCleaner cleaner = new SimpleStaleClassCleaner(taskOutputs);
        cleaner.addDirToClean(spec.getDestinationDir());
        cleaner.execute();
        return delegate.execute(spec);
    }
}
